Flake8-SARIF
============

This is a plugin for Flake8 that will format the output as SARIF.


Installation
------------

.. code-block:: bash

    pip install flake8-sarif


Usage
-----

.. code-block:: bash

    flake8 --format=sarif ...


Competitors
-----------

None that I could find on PyPI


Maintenance Policy
------------------

This project is seeking maintainers. Please open an issue if you're interested
and ensure that you've read the PyCQA's `Code of Conduct`_.


.. _Code of Conduct:
    http://meta.pycqa.org/en/latest/code-of-conduct.html
